<?php
/**
* bp_code_snippets_dtheme_header_nav_setup
* Adds a link to Snippets Public Directory in BP main nav items
* 
*/
function bp_code_snippets_dtheme_header_nav_setup() {
	global $bp;

	$selected = ( bp_is_page( BP_CS_SLUG ) ) ? ' class="selected"' : '';
	$title = __( 'Snippets', 'bp-code-snippets' );

	echo sprintf('<li%s><a href="%s/%s" title="%s">%s</a></li>', $selected, get_option('home'), BP_CS_SLUG, $title, $title );
}
add_action( 'bp_nav_items', 'bp_code_snippets_dtheme_header_nav_setup');

/**
* bp_code_snippets_directory_snippets_setup
* loads the template main-home if directory is displayed
* 
*/
function bp_code_snippets_directory_snippets_setup() {
	global $bp;

	if ( $bp->current_component == BP_CS_SLUG && empty( $bp->current_action ) && empty( $bp->current_item ) ) {
		$bp->is_directory = true;
		wp_enqueue_style('code_snippets_style', BP_CS_PLUGIN_URL . '/css/bp-cs.css');
		do_action( 'bp_code_snippets_directory_snippets_setup' );
		bp_core_load_template('code-snippets/main-home');
	}
}
add_action( 'wp', 'bp_code_snippets_directory_snippets_setup', 2 );

/**
* bp_code_snippets_dir_add_js
* Adds a specific js script to check if a group has been selected when clicking on Add Snippet button
* 
*/
function bp_code_snippets_dir_add_js(){
	global $bp;
	?>
	<script type="text/javascript">
	function addSnippetInGroup(group_url){
		if(group_url==0){
			alert("<?php _e('Please select the group where you want to add your snippet!','bp-code-snippets');?>");
			jQuery("#snippets-group").focus();
		}
		else{
			group_url = "<?php echo bp_get_root_domain();?>/groups/"+group_url+"/<?php echo $bp->snippets->slug;?>/add/";
			location.href = group_url;
		}
	}
	</script>
	<?php
}

/**
* code_snippets_dir_active_user_num
* template tag to retrieve the number of snippets of the loggedin user for snippets public directory
* 
*/
function code_snippets_dir_active_user_num(){
	global $bp;
	return bp_code_snippets_num_active_user($bp->loggedin_user->id);
}

/**
* bp_code_snippets_action_directory_feed
* Registers the template for the snippets public directory rss feed
* 
*/
function bp_code_snippets_action_directory_feed() {
	global $bp, $wp_query;

	if ( $bp->current_component != $bp->snippets->slug || $bp->current_action != 'feed' )
		return false;

	$wp_query->is_404 = false;
	status_header( 200 );

	include_once( 'feeds/all-snippets.php' );
	die();
}
add_action( 'bp_init', 'bp_code_snippets_action_directory_feed', 6 );

/**
* bp_directory_bp_code_snippets_feed_link
* Display the rss feed for the snippets public directory.
* 
*/
function bp_directory_bp_code_snippets_feed_link() {
	echo bp_get_directory_bp_code_snippets_feed_link();
}
	function bp_get_directory_bp_code_snippets_feed_link() {
		global $bp;
		return apply_filters( 'bp_directory_bp_code_snippets_feed_link', site_url( $bp->snippets->slug . '/feed' ) );
	}

/**
* bp_code_snippets_dtheme_search_form
* Display the search form for the snippets public directory.
* 
*/
function bp_code_snippets_dtheme_search_form() {
	global $bp; ?>
	<form action="<?php echo bp_get_root_domain().'/'.$bp->snippets->slug.'/';?>" method="get" id="snippets-links-form">
		<label><input type="text" name="q" id="snippets_search" value="<?php if ( isset( $_GET['q'] ) ) { echo attribute_escape( $_GET['q'] ); } else { _e( 'Search anything...', 'buddypress' ); } ?>"  onfocus="if (this.value == '<?php _e( 'Search anything...', 'buddypress' ) ?>') {this.value = '';}" onblur="if (this.value == '') {this.value = '<?php _e( 'Search anything...', 'buddypress' ) ?>';}" /></label>
		<input type="submit" id="snippets_search_submit" value="<?php _e( 'Search', 'bp-code-snippets' ) ?>" />
	</form> <?php
}

/**
* bp_code_snippets_dir_list_snippets
* Display all the public snippets.
* 
*/
function bp_code_snippets_dir_list_snippets(){
	global $bp, $wpdb;
	$paged = 1;
	if(isset($_GET['paged'])){
		$paged = intval($_GET['paged']);
	}
	$cat="";
	$compreq ="";
	$query="";
	if(isset($_GET['cat'])){
		$cat = $_GET['cat'];
		$compreq = "AND snippet_type='".$cat."'";
		$url_req = 'cat='.$cat.'&';
	}
	elseif(isset($_GET['q'])){
		$query = $_GET['q'];
		$compreq = "AND (snippet_title LIKE '%".$query."%' OR snippet_purpose LIKE '%".$query."%' OR snippet_content LIKE '%".$query."%')";
		$url_req = 'q='.$query.'&';
	}
	$limit=10;
	$offset=0;
	$offset = $limit * ($paged - 1);
	$all_count = bp_code_snippets_num_active_user(0, $cat, $query);
	$max_pages = ceil($all_count / $limit);
	$table_cs = $wpdb->base_prefix.'code_snippets';
	$table_group = $wpdb->base_prefix.'bp_groups';
	$user_snippets = $wpdb->get_results("SELECT id_cs, id_group, id_user, date_cs, snippet_title, snippet_type, snippet_purpose, cs_comment_count FROM ".$table_cs." LEFT JOIN ".$table_group." ON(".$table_cs.".id_group = ".$table_group.".id) WHERE ".$table_group.".status='public' ".$compreq." ORDER BY date_cs DESC LIMIT ".$offset.",".$limit);
	?>
	<div id="snippet_list">
	<?php foreach($user_snippets as $snippet){
		$user_info = get_userdata($snippet->id_user);
		$group_info = bp_code_snippet_get_infos_goup($snippet->id_group);
		$group_permalink = site_url().'/'.BP_GROUPS_SLUG.'/'.$group_info->slug.'/';
		$snippet_permalink = $group_permalink.BP_CS_SLUG.'/';
		if(groups_is_user_member( $bp->loggedin_user->id, $snippet->id_group ) || $bp->loggedin_user->id==$snippet->id_user || $group_info->status == 'public'){
		?>
		<div class="item-cs" id="cs_<?php echo $snippet->id_cs;?>">
			<div class="avatar-cs-author">
				<a href="<?php echo site_url() ?>/<?php echo BP_MEMBERS_SLUG ;?>/<?php echo $user_info->user_nicename;?>" title="<?php echo $user_info->user_nicename;?>" rel="nofollow">
				<?php echo bp_core_fetch_avatar('item_id=' . $snippet->id_user . '&type=full&width=64&height=64' ) ?>
				</a>
			<span class="cs-comment-num"><a href="<?php echo $snippet_permalink;?>single/<?php echo $snippet->id_cs;?>/" title="<?php echo $snippet->cs_comment_count;?> <?php _e('comment(s)', 'bp-code-snippets');?>"><?php echo $snippet->cs_comment_count;?></a></span>
			</div>
			<div class="item-cs-desc">
			<div class="cs_meta"><span class="highlight"><?php _e('Added by', 'bp-code-snippets');?> <a href="<?php echo site_url() ?>/<?php echo BP_MEMBERS_SLUG ;?>/<?php echo $user_info->user_nicename;?>" rel="nofollow">@<?php echo $user_info->user_nicename;?></a></span>&nbsp;<?php _e('on', 'bp-code-snippets');?> <?php echo mysql2date(get_option('date_format'), $snippet->date_cs);?>&nbsp;<?php _e('at', 'bp-code-snippets');?>&nbsp;<?php echo mysql2date(get_option('time_format'), $snippet->date_cs);?> <?php _e('in category', 'bp-code-snippets');?> 
			<?php if(groups_is_user_member( $bp->loggedin_user->id, $snippet->id_group )):?>
				<a href="<?php echo $snippet_permalink;?>?cat=<?php echo $snippet->snippet_type;?>"><img src="<?php echo BP_CS_PLUGIN_URL;?>/images/<?php echo $snippet->snippet_type;?>.gif" alt="<?php echo $snippet->snippet_type;?>"/>&nbsp;<i><?php echo strtoupper($snippet->snippet_type);?></i></a>
				<?php else:?>
					<img src="<?php echo BP_CS_PLUGIN_URL;?>/images/<?php echo $snippet->snippet_type;?>.gif" alt="<?php echo $snippet->snippet_type;?>"/>&nbsp;<i><?php echo strtoupper($snippet->snippet_type);?></i>
				<?php endif;?>
				 <?php _e('of the group', 'bp-code-snippets');?> <i><a href="<?php echo $group_permalink;?>" title="<?php _e('Go to group ', 'bp-code-snippets').$group_info->name;?>"><?php echo $group_info->name;?></a></i>
			</div>
			<div class="cs-content">
				<h3>
					<?php if(groups_is_user_member( $bp->loggedin_user->id, $snippet->id_group )):?>
						<a href="<?php echo $snippet_permalink;?>single/<?php echo $snippet->id_cs;?>/" title="<?php _e('Read more', 'bp-code-snippets');?>"><?php echo stripslashes($snippet->snippet_title);?></a>
					<?php else:?>
						<?php echo stripslashes($snippet->snippet_title);?>
					<?php endif;?>
				</h3>
				<p><?php echo substr(stripslashes($snippet->snippet_purpose), 0,250);?>
				<?php if(strlen(stripslashes($snippet->snippet_purpose))>250):?>
					&nbsp;... 
					<?php if(groups_is_user_member( $bp->loggedin_user->id, $snippet->id_group )):?>
					<a href="<?php echo $snippet_permalink;?>single/<?php echo $snippet->id_cs;?>/" title="<?php echo $snippet->snippet_title;?>"><?php _e('Read more', 'bp-code-snippets');?></a>
					<?php endif;?>
				<?php endif;?>	
				</p>
			</div>
			</div>
		</div>
<?php
		}
	}
?>
	</div>
	<div class="bp-cs-pagination">

	   <?php
	    $page_links = paginate_links( array(
	        'base' => site_url( $bp->snippets->slug).'/?'.$url_req.'%_%',//'/'.add_query_arg( 'paged', '%#%' ),
	        'format' => 'paged=%#%',
	        'prev_text' => __('&laquo;'),
	        'next_text' => __('&raquo;'),
	        'total' => $max_pages,
	        'current' => $paged
	     ));
	    ?>

	<?php if ( $page_links ) { ?>
		<div class="pagination-links-cs"><?php $page_links_text = sprintf( '<span class="displaying-num">' . __( 'Displaying %s&#8211;%s of %s' ) . '</span>%s',
		number_format_i18n( $offset+1 ),
		number_format_i18n( $offset + count($user_snippets) ),
		number_format_i18n( $all_count ),
		$page_links
	); echo $page_links_text."</div>"; ?>

	<?php } ?>
	</div>
	<?php
}

/**
* bp_code_snippets_cat_code
* list categories of code for snippets public directory
* 
*/
function bp_code_snippets_directory_cat(){
	global $bp,$wpdb;
	$table_cs = $wpdb->base_prefix.'code_snippets';
	$table_group = $wpdb->base_prefix.'bp_groups';
	$current_url = site_url( $bp->snippets->slug).'/';
	$cat_snippets = $wpdb->get_results("SELECT snippet_type, count(*) as nbre FROM ".$table_cs." LEFT JOIN ".$table_group." ON(".$table_cs.".id_group = ".$table_group.".id) WHERE ".$table_group.".status='public' GROUP BY snippet_type");
	?>
	<?php if(count($cat_snippets)>1):?>
			<?php if(!isset($_GET['cat'])):?>
				<li class="current">
			<?php else:?>
				<li>
			<?php endif;?>
			<a href="<?php echo $current_url;?>"><?php _e('Display All', 'bp-code-snippets');?></a></li>
			<?php foreach($cat_snippets as $cat):?>
				<?php if(isset($_GET['cat']) && $_GET['cat'] == $cat->snippet_type):?>
					<li class="current">
				<?php else:?>
					<li>
				<?php endif;?>
					<a href="<?php echo $current_url;?>?cat=<?php echo $cat->snippet_type;?>"><?php echo ucfirst($cat->snippet_type);?> (<?php echo $cat->nbre;?>)</a>
				</li>
			<?php endforeach;?>	
	<?php endif;?>
	<?php
}

function bp_code_snippets_list_cs_enable_groups(){
	global $bp, $wpdb;
	$table_group_meta = $wpdb->base_prefix.'bp_groups_groupmeta';
	$table_group = $wpdb->base_prefix.'bp_groups';
	$snippets_enable_groups = $wpdb->get_results("SELECT ".$table_group.".id, name, slug FROM ".$table_group." LEFT JOIN ".$table_group_meta." ON(".$table_group.".id = ".$table_group_meta.".group_id) WHERE ".$table_group_meta.".meta_key='snippets_code_ok'");
	?>
	<select name="cat" id="snippets-group" class="snippets-group">
		<option value="0"><?php _e('Group','bp-code-snippets');?></option>
		<?php foreach($snippets_enable_groups as $cs_group):?>
			<?php if(groups_is_user_member( $bp->loggedin_user->id, $cs_group->id )):?>
				<option value="<?php echo $cs_group->slug;?>"><?php echo $cs_group->name;?></option>
			<?php endif;?>
		<?php endforeach;?>
	</select>
	<?php
}

?>